function [rho_mud,bulk_m,kv_table,rho_table,yp,pv] = Fluid_Parameters(fluid_type)

if fluid_type==1     %Sea Water (Newtonian Fluid)
    rho_mud=1030;    %[kg/m3] Density Mud 
    bulk_m=2.34;     %[GPa] Bulk Modulus 
    dyn_visc=0.00149;%[Pa-s] Dynamic Viscocity Sea Water  
    yp=0;            %[Cp] Yield Point (Only in use for WBM, but must be defined)
    pv=0;            %[lb/100ft] Plastic Viscosity
    
elseif fluid_type==2 %WBM #1 (Non-Newtonian Bingham Plastic Fluid)
    rho_mud=1150;     %[kg/m3] Mud Density
    bulk_m=2.34;      %[GPa] Bulk Modulus 
    yp=12;            %[Cp] Yield Point 
    pv=13;            %[lb/100ft] Plastic Viscosity
    dyn_visc=0.00149; %[pa-s] Kinemtaic viscosity (Only in use for sea water, but must be defined)
    
elseif fluid_type==3 %WBM #2 (Non-Newtonian Bingham Plastic Fluid)
    rho_mud=1250;     %[kg/m3] Mud Density
    bulk_m=2.34;      %[GPa] Bulk Modulus
    yp=16.2;          %[Cp] Yield Point 
    pv=19;            %[lb/100ft] Plastic Viscosity
    dyn_visc=0.00149; %[mm2/s] Kinemtaic viscosity (Only in use for sea water, but must be defined)
end

%% Constructing Tables for Density and Kinetmatic Viscosity
kin_visc=(dyn_visc/rho_mud)*10^6; %[mm2/s] Kinemtaic viscosity Sea Water
kv_table=kin_visc.*ones(11,12);%[mm2/s] Kinemtaic viscosity Table (only in use for sea water)
rho_table=zeros(11,12); %[kg/m3] Mud density table
a=0.00001;
for i =1:12    
    rho_table(:,i)=rho_mud+a;
    a=a+0.000001;
end

end     
