%% -Input Data-

% *Condutor Section*
ID_con=28;    %[in] Conductor inner diameter 
L_con=50;     %[m]  Conductor length 
  
% *Surface Casing Section*
OD_csg=20;       %[in] Surface casing outer diameter
ID_csg=18.73;    %[in] Surface casing inner diameter 
L_csg=400;       %[m]  Surface casing length (from seabed) 
hs_2=26;         %[in] Hole size surface casing section 
L_st=24;         %[m]  Length shoe track (2 joints of 12m)

% *Various*
P_so=1000;     %[psi]   Shear-out pressure wiper plug(shaer pin strength) Low(800-1000psi)/High(2000-2500psi) 
h_water=450;   %[m]     Water depth 
rho_ob= 2200;  %[kg/m3] Density sediments/rock in the atop hole (CHANGE LATER to something referenced)
ID_sl=6;       %[in]    Inner diameter SMO valve to suction line 
ID_fe=3.25;    %[in]    Inner diameter of float equipment (float collar/ flaot shoe)
rho_sw=1030;   %[kg/m3] Density Seawater 

% Fluid Selection
fluid_type=2;  %Selection of fluid type: 1=Sea Water, 2=WBM #1, 3=WBM #2 


%% -Oilfield to SI-Unit Converter-

% Conversion factors and physical constants%
in_m=0.0254;       %[in to m]
psi_pa=6894.75;    %[psi to pa]
g=9.81;            %[m/s^2] Gravity 

% -Converter
ID_con=ID_con*in_m;
OD_csg=OD_csg*in_m;
ID_csg=ID_csg*in_m; 
hs_2=hs_2*in_m;
P_so=P_so*psi_pa; 
ID_sl=ID_sl*in_m; 
ID_fe=ID_fe*in_m;

%% Retrieving Fluid Properties 
[rho_mud,bulk_m,kv_table,rho_table,yp,pv]=Fluid_Parameters(fluid_type);
 

%% Area Calculations
A_csg_o=(pi/4)*OD_csg^2;   %[m^2] Cross area outer, surface casing 
A_csg_i=(pi/4)*ID_csg^2;   %[m^2] Cross area inner, surface casing
A_con_i=(pi/4)*ID_con^2;   %[m^2] Cross area inner, conductor casing
A_oh=(pi/4)*hs_2^2;        %[m^2] Cross area open hole, surf casing section
A_ann_ch=A_con_i-A_csg_o;  %[m^2] Annular cross area cased hole
A_ann_oh=A_oh-A_csg_o;     %[m^2] Annular cross area open hole
A_fe=(pi/4)*ID_fe^2;       %[m^2] Cross area valves float equipment (float collar/ flaot shoe)
A_sl=(pi/4)*ID_sl^2;       %[m^2] Cross area RMR-valve to suction line
dh_ann_oh=(hs_2-OD_csg);   %[m] Hydraulic Diameter Open Hole 
dh_ann_ch=(ID_con-OD_csg); %[m] Hydraulic Diameter Cased Hole

%% Down Hole Pressure Calculations 
P_wh=g*rho_sw*h_water;            %[pa] Pressure at wellhead
P_fc=P_wh+g*rho_mud*(L_csg-L_st); %[Pa] Pressure float collar
P_bh=P_wh+g*rho_mud*(L_csg);      %[pa] Pressure bottom hole
P_cs=P_wh+g*rho_mud*L_con;        %[pa] Pressure conductor shoe
P_flow=0.0055*10^6;               %[pa] Fictional pressure to achive cmt displacement rate

%% Load Model
load_system("Pressure_Pulse_Model"); 
   
%% Insert Fluid Data and Pressure Loss   
if fluid_type==1
    set_param('Pressure_Pulse_Model/Open Hole Annulus','pressure_loss_spec','1');
    set_param('Pressure_Pulse_Model/Cased Hole Annulus','pressure_loss_spec','1');
    set_param('Pressure_Pulse_Model/Surface Casing','pressure_loss_spec','1');
    set_param('Pressure_Pulse_Model/Shoe Track','pressure_loss_spec','1');
    
elseif fluid_type==2 || fluid_type==3
    q_matrix=(linspace(0.1,40,200))./60;                                             %[m3/s] Flow Rate Matrix
    m_matrix=q_matrix.*rho_mud;                                                      %[kg/s] Mass Flow Rate Matrix
    dp_matrix_csg=dp_nnf_casing(ID_csg,L_csg-L_st,rho_mud,q_matrix,yp,pv);           %[Pa]P-Loss Casing
    dp_matrix_st=dp_nnf_casing(ID_csg,L_st,rho_mud,q_matrix,yp,pv);                  %[pa]P-Loss Shoe Track
    dp_matrix_ann_oh=dp_nnf_annular(OD_csg,hs_2,L_csg-L_con,rho_mud,q_matrix,yp,pv); %[pa]P-Loss Cased Hole Annular
    dp_matrix_ann_ch=dp_nnf_annular(OD_csg,ID_con,L_con,rho_mud,q_matrix,yp,pv);     %[pa]P-Loss Open Hole Annular 
    set_param('Pressure_Pulse_Model/Open Hole Annulus','pressure_loss_spec','3','mdot_nominal','m_matrix','p_diff_nominal','dp_matrix_ann_oh');
    set_param('Pressure_Pulse_Model/Cased Hole Annulus','pressure_loss_spec','3','mdot_nominal','m_matrix','p_diff_nominal','dp_matrix_ann_ch');
    set_param('Pressure_Pulse_Model/Surface Casing','pressure_loss_spec','3','mdot_nominal','m_matrix','p_diff_nominal','dp_matrix_csg');
    set_param('Pressure_Pulse_Model/Shoe Track','pressure_loss_spec','3','mdot_nominal','m_matrix','p_diff_nominal','dp_matrix_st');  
end

set_param('Pressure_Pulse_Model/TL Settings','rho_ref_3','rho_mud','beta_const_3','bulk_m',...
     'nu_TLU','kv_table','rho_TLU_2','rho_table'); %Fluid settings for fluid network
 
%% Insert Component Data Into Model   
set_param('Pressure_Pulse_Model/Casing Hanger','area','A_csg_i','reservoir_pressure','P_wh+P_flow'); 
 
set_param('Pressure_Pulse_Model/Wiper Plug','area','A_csg_i');
 
set_param('Pressure_Pulse_Model/Surface Casing','pipe_length','L_csg-L_st','elevation_gain','-(L_csg-L_st)',...
     'area','A_csg_i','p0_vec','[P_wh,P_fc]','Dh_rigid','ID_csg','inertia','1');
 
set_param('Pressure_Pulse_Model/Shoe Track','pipe_length','L_st','elevation_gain','-L_st',...
     'area','A_csg_i','p0_vec','[P_fc,P_bh]','Dh_rigid','ID_csg','inertia','1');
 
set_param('Pressure_Pulse_Model/Casing-->Open Hole','area_A','A_oh','area_B','A_csg_i');

set_param('Pressure_Pulse_Model/Open Hole-->Annulus','area_A','A_oh','area_B','A_ann_oh');
  
set_param('Pressure_Pulse_Model/Open Hole Annulus','pipe_length','L_csg-L_con','elevation_gain','L_csg-L_con',...
     'area','A_ann_oh','p0_vec','[P_bh,P_cs]','Dh_rigid','dh_ann_oh','inertia','1');
 
set_param('Pressure_Pulse_Model/Cased Hole Annulus','pipe_length','L_con','elevation_gain','L_con',...
     'area','A_ann_ch','p0_vec','[P_cs,P_wh]','Dh_rigid','dh_ann_ch','inertia','1')
 
set_param('Pressure_Pulse_Model/Float Collar Valve','area','A_csg_i','diam_orifice','ID_fe'); 
 
set_param('Pressure_Pulse_Model/Float Shoe Valve','area','A_csg_i','diam_orifice','ID_fe');
 
set_param('Pressure_Pulse_Model/Sea','area','A_sl','reservoir_pressure','P_wh');

set_param('Pressure_Pulse_Model/Pump Inlet','area','A_sl','reservoir_pressure','P_wh');
 
set_param('Pressure_Pulse_Model/MPC Valve1','area','A_ann_ch','diam_orifice','ID_sl');

set_param('Pressure_Pulse_Model/MPC Valve2','area','A_ann_ch','diam_orifice','ID_sl');

%% Simulation
Results= sim('Pressure_Pulse_Model'); %Performs the simulations
 
%% Organization and Plotting

%Pressure
PRes_Top_Casing=Results.P_Top_Casing;
PRes_Top_Shoe_Track=Results.P_Top_Shoe_Track;
PRes_Bottom_Hole=Results.P_Bottom_Hole;
PRes_Con_Shoe=Results.P_Conductor_Shoe;
PRes_Top_Annulus=Results.P_Top_Annulus;

%Flow
QRes_Top_Casing=Results.Q_Top_Casing;
QRes_Top_Shoe_Track=Results.Q_Top_Shoe_Track;
QRes_Bottom_Hole=Results.Q_Bottom_Hole;
QRes_Con_Shoe=Results.Q_Conductor_Shoe;
QRes_Top_Annulus=Results.Q_Top_Annulus;

% Plotting Results 
figure(1)
plot(PRes_Top_Casing(:,1),PRes_Top_Casing(:,2)./10^5,'b','LineWidth',1);
title('Pressure Top Casing')
xlabel('Time[s]')
ylabel('Pressure [Bar]')
grid on

figure(2)
plot(PRes_Top_Shoe_Track(:,1),PRes_Top_Shoe_Track(:,2)./10^5,'b','LineWidth',1)
title('Pressure Top Shoe Track')
xlabel('Time[s]')
ylabel('Pressure [Bar]')
grid on

figure(3)
plot(PRes_Bottom_Hole(:,1),PRes_Bottom_Hole(:,2)./10^5,'b','LineWidth',1)
title('Pressure Bottom Hole')
xlabel('Time[s]')
ylabel('Pressure [Bar]')
grid on

figure(4)
plot(PRes_Con_Shoe(:,1),PRes_Con_Shoe(:,2)./10^5,'b','LineWidth',1)
title('Pressure Conductor Shoe')
xlabel('Time[s]')
ylabel('Pressure [Bar]')
grid on

figure(5)
plot(PRes_Top_Annulus(:,1),PRes_Top_Annulus(:,2)./10^5,'b','LineWidth',1)
title('Pressure Top Annulus')
xlabel('Time[s]')
ylabel('Pressure [Bar]')
grid on

figure(6)
plot(QRes_Top_Casing(:,1),QRes_Top_Casing(:,2),'r','LineWidth',1)
title('Volumetric Flow Top Casing')
xlabel('Time[s]')
ylabel('Volumetric Flow [m3/s]')
grid on

figure(7)
plot(QRes_Top_Shoe_Track(:,1),QRes_Top_Shoe_Track(:,2),'r','LineWidth',1)
title('Volumetric Flow Top Shoe Track')
xlabel('Time[s]')
ylabel('Volumetric Flow [m3/s]')
grid on

figure(8)
plot(QRes_Bottom_Hole(:,1),QRes_Bottom_Hole(:,2),'r','LineWidth',1)
title('Volumetric Flow Bottom Hole')
xlabel('Time[s]')
ylabel('Volumetric Flow [m3/s]')
grid on

figure(9)
plot(QRes_Con_Shoe(:,1),QRes_Con_Shoe(:,2),'r','LineWidth',1)
title('Volumetric Flow Conductor Shoe')
xlabel('Time[s]')
ylabel('Volumetric Flow [m3/s]')
grid on

figure(10)
plot(QRes_Top_Annulus(:,1),QRes_Top_Annulus(:,2),'r','LineWidth',1)
title('Volumetric Flow Top Annulus')
xlabel('Time[s]')
ylabel('Volumetric Flow [m3/s]')
grid on

%% Results Into Table

%Initial Pressure at system locations
P_Initial=[PRes_Top_Casing(1,2),PRes_Top_Shoe_Track(1,2),PRes_Bottom_Hole(1,2),PRes_Con_Shoe(1,2),...
    PRes_Top_Annulus(1,2)]./10^5; %[bar]
%Maxima of pressure experienced during pulse migration 
P_Max=[max(PRes_Top_Casing(:,2)),max(PRes_Top_Shoe_Track(:,2)),max(PRes_Bottom_Hole(:,2)),...
    max(PRes_Con_Shoe(:,2)),max(PRes_Top_Annulus(:,2))]./10^5; %[Bar]

%Minima of pressure experienced during pulse migration
P_Min=[min(PRes_Top_Casing(:,2)),min(PRes_Top_Shoe_Track(:,2)),min(PRes_Bottom_Hole(:,2)),...
    min(PRes_Con_Shoe(:,2)),min(PRes_Top_Annulus(:,2))]./10^5; %[Bar]

%Magnitude of pulse component (that are on top of initial pressure)
P_Pulse=(P_Max-P_Initial); %[Bar] 

%Magnitude of pulse dampening
P_Dampening=P_Pulse(1,1)-P_Pulse; %[Bar] 


Description=["Top Casing", "Top Shoe Track", "Bottom Hole", "Conductor Shoe","Top Annulus"]; %Locations 
PRes_Table=table(["Description [Bar]";Description'], ["Initial Pressure [Bar]"; P_Initial'],...
    ["Pressure Max [Bar]";P_Max'],["Pressure Min [Bar]";P_Min'], ["Pulse Magnitude [Bar]";P_Pulse'],...
    ["Pulse Dampening [Bar]";P_Dampening']);
disp(PRes_Table)

