%Note: The equations used for calcualting the frictional pressure losses below are 
%the same equaitons as described in section 4.5.3 in the thesis, only that they 
%are provided in oil-field units in this code and in SI-units in thesis.
%The source of the equations are cited as  Guo and Liu (2011) in the thesis.

function [dp_matrix_ann]=dp_nnf_annular (OD_csg,hs,L_ann,rho_mud,q_matrix,yp,pv)

dp_matrix_ann=zeros(1,length(q_matrix));%Pre-allocation of pressure loss matrix annulus

%% SI to Oil Field Units (ppg,ft/s,gpm,in,cp)
hs=hs/0.0254;                        %[in] 
OD_csg=OD_csg/0.0254;                %[in]
rho_mud=rho_mud*0.008345;            %[ppg]
L_ann=L_ann*3.281;                   %[ft]
q_matrix=q_matrix.*(60*1000/3.7854); %[gpm] 
 
%% Constructing Pressure Loss Matrix for Annular Conduit
for i=1:length(q_matrix)
    
%Fluid Velocity in the Annulus
v_a=q_matrix(i)/(2.448*(hs^2-OD_csg^2)); %[ft/s] Fluid Velocity

%Apparent Viscosity
mua_ann=pv+(5*yp*(hs-OD_csg))/v_a; %[cp] Apparent Viscosity

%Reynolds Number and Flow Regime
Re_ann=(757*rho_mud*v_a*(hs-OD_csg))/mua_ann; %[unitless] Reynolds Number

if Re_ann<=2000%Laminar Pressure Drop 
    dp_ann=((pv*v_a)/(1000*(hs-OD_csg)^2) + yp/(200*(hs-OD_csg)))*L_ann; %[psi] Laminar Pressure Loss 
   
elseif Re_ann>2000 && Re_ann<=4000                                              %Transitional Flow Pressure Drop
    lam=((pv*v_a)/(1000*(hs-OD_csg)^2) + yp/(200*(hs-OD_csg)))*L_ann;           %[psi] Laminar Pressure Loss
    turb=(((rho_mud^0.75)*(v_a^1.75)*(pv^0.25))/(1396*(hs-OD_csg)^1.25))*L_ann; %[psi] Turbulent Pressure Loss
    dp_ann=(lam+turb)/2;                                                        %Average Laminar and Turbulent pressure drop
    
elseif Re_ann>4000 %Turbulent Pressure Drop
    dp_ann=(((rho_mud^0.75)*(v_a^1.75)*(pv^0.25))/(1396*(hs-OD_csg)^1.25))*L_ann; %[psi] Turbulent Pressure Loss
end

dp_matrix_ann(i)=dp_ann*6894.7572932; %[Pa] Pressure loss matrix annulus

end
end
