%Note: The equations used for calcualting the frictional pressure losses below are 
%the same equaitons as described in section 4.5.3 in the thesis, only that they 
%are provided in oil-field units in this code and in SI-units in thesis.
%The source of the equations are cited as  Guo and Liu (2011) in the thesis.

function [dp_matrix_csg]=dp_nnf_casing (ID_csg,L_csg,rho_mud,q_matrix,yp,pv)

dp_matrix_csg=zeros(1,length(q_matrix));   %Pre-allocation of pressure loss matrix casing

%% SI to Oil Field Units (ppg,ft/s,gpm,in,cp) %%
ID_csg=ID_csg/0.0254;                %[in] 
rho_mud=rho_mud*0.008345;            %[ppg]
L_csg=L_csg*3.281;                   %[ft]
q_matrix=q_matrix.*(60*1000/3.7854); %[gpm] 
 
%% Constructing Pressure Loss Matrix for Casing Pipe
for i=1:length(q_matrix)
    
%Fluid Velocity in Casing
v_c=q_matrix(i)/(2.448*ID_csg^2);          %[ft/s] 

%Apparent Viscosity
mua_pipe=pv+(6.66*yp*ID_csg)/v_c;          %[cp]

%Reynolds Number and Flow Regime
Re_pipe=(928*rho_mud*v_c*ID_csg)/mua_pipe; %[unitless]

if Re_pipe<=2000                                                           %Laminar Pressure Drop 
    dp_csg=((pv*v_c)/(1500*ID_csg^2)+yp/(225*ID_csg))*L_csg;               %[psi] Laminar Pressure Drop
    
    elseif Re_pipe>2000 && Re_pipe<=4000                                   %Transitional Flow Pressure Drop
    lam=((pv*v_c)/(1500*ID_csg^2)+yp/(225*ID_csg))*L_csg;                  %[psi] Laminar Pressure Drop
    turb=(((rho_mud^0.75)*(v_c^1.75)*(pv^0.25))/(1800*ID_csg^1.25))*L_csg; %[psi] Turbulent Pressure Drop
    dp_csg=(lam+turb)/2; %Average Laminar and Turbulent pressure drop
    
    elseif Re_pipe>4000 %Turbulent Pressure Drop
    dp_csg=(((rho_mud^0.75)*(v_c^1.75)*(pv^0.25))/(1800*ID_csg^1.25))*L_csg;%[psi] Turbulent Pressure Drop
end

dp_matrix_csg(i)=dp_csg*6894.7572932;  %[Pa] Pressure loss matrix

end
end
